@@ -1006,34 +1006,36 @@ symmetry_grade <- function(Q,
 #'
 #' @noRd
 warn_not_aggregating <- function(formula, data, formula_covariates, always) {
-  if (always || is_not_testing_or_snapshot()) {
-    nms_predictors <- all.vars(formula[[3L]])
-    has_covariates <- !is.null(formula_covariates)
-    if (has_covariates) {
-      nms_covariates <- all.vars(formula_covariates[[2L]])
-      nms_predictors <- union(nms_predictors, nms_covariates)
-    }
-    predictors <- data[nms_predictors]
-    has_dup <- any(duplicated(predictors))
-    if (has_dup) {
-      dir_cache <- tools::R_user_dir(package = "bage", which = "cache")
-      dir.create(dir_cache, showWarnings = FALSE, recursive = TRUE)
-      path <- file.path(dir_cache, "aggregation.txt")
-      aggregation_file_exists <- file.exists(path)
-      time_now <- as.numeric(Sys.time())
-      if (aggregation_file_exists)
-        time_last <- as.numeric(readLines(path, warn = FALSE))
-      else
-        time_last <- 0
-      is_eight_hours_or_more <- time_now - time_last > 8 * 3600
-      if (is_eight_hours_or_more) {
-        cli::cli_warn(c("{.arg data} has multiple rows with the same values for the predictor{?s} ({.var {nms_predictors}}). Model behavior when predictors are duplicated has changed since version 0.9.8.",
-                        i = "Up to version 0.9.8, rows with duplicated values were aggregated before fitting. From version 0.9.9 no aggregation occurs.",
-                        i = "See help for {.fun fit} for details.",
-                        i = "(This warning will only be shown once every 8 hours)."))
-        writeLines(as.character(time_now), path)
-      }
-    }
+  if (!interactive())
+    return(invisible(TRUE))
+  if (!(always || is_not_testing_or_snapshot()))
+    return(invisible(TRUE))
+  nms_predictors <- all.vars(formula[[3L]])
+  has_covariates <- !is.null(formula_covariates)
+  if (has_covariates) {
+    nms_covariates <- all.vars(formula_covariates[[2L]])
+    nms_predictors <- union(nms_predictors, nms_covariates)
+  }
+  predictors <- data[nms_predictors]
+  has_dup <- any(duplicated(predictors))
+  if (!has_dup)
+    return(invisible(TRUE))
+  dir_cache <- tools::R_user_dir(package = "bage", which = "cache")
+  dir.create(dir_cache, showWarnings = FALSE, recursive = TRUE)
+  path <- file.path(dir_cache, "aggregation.txt")
+  aggregation_file_exists <- file.exists(path)
+  time_now <- as.numeric(Sys.time())
+  if (aggregation_file_exists)
+    time_last <- as.numeric(readLines(path, warn = FALSE))
+  else
+    time_last <- 0
+  is_eight_hours_or_more <- time_now - time_last > 8 * 3600
+  if (is_eight_hours_or_more) {
+    cli::cli_warn(c("{.arg data} has multiple rows with the same values for the predictor{?s} ({.var {nms_predictors}}). Model behavior when predictors are duplicated has changed since version 0.9.8.",
+                    i = "Up to version 0.9.8, rows with duplicated values were aggregated before fitting. From version 0.9.9 no aggregation occurs.",
+                    i = "See help for {.fun fit} for details.",
+                    i = "(This warning will only be shown once every 8 hours)."))
+    writeLines(as.character(time_now), path)
   }
   invisible(TRUE)
 }
