@@ -2,6 +2,8 @@
 test_that("'get_matrix_or_offset_svd' works with age main effect, type is total, matrix", {
     ssvd <- sim_ssvd()
     ans_obtained <- get_matrix_or_offset_svd(ssvd,
+                                             v = "v1",
+                                             nm_ssvd = "SSVD",
                                              levels_age = c("0-4", "5-9"),
                                              levels_sex = NULL,
                                              joint = NULL,
@@ -13,9 +15,48 @@ test_that("'get_matrix_or_offset_svd' works with age main effect, type is total,
     expect_equal(ans_obtained, ans_expected)
 })
 
+test_that("'get_matrix_or_offset_svd' works with age main effect, type is total, matrix - no v supplied", {
+    ssvd <- sim_ssvd()
+    ans_obtained <- get_matrix_or_offset_svd(ssvd,
+                                             v = NULL,
+                                             nm_ssvd = "SSVD",
+                                             levels_age = c("0-4", "5-9"),
+                                             levels_sex = NULL,
+                                             joint = NULL,
+                                             agesex = "age",
+                                             get_matrix = TRUE,
+                                             n_comp = 3L)
+    ans_expected <- Matrix::Matrix(1, nr = 2, nc = 3, 
+                                         dimnames = list(c("0-4", "5-9"), NULL))
+    expect_equal(ans_obtained, ans_expected)
+})
+
+
+test_that("'get_matrix_or_offset_svd' v argument works", {
+  ssvd <- sim_ssvd()
+  data1 <- ssvd$data
+  data2 <- ssvd$data
+  data2$version <- "v2"
+  ssvd$data <- rbind(data1, data2)
+  ans_obtained <- get_matrix_or_offset_svd(ssvd,
+                                           v = "v2",
+                                           nm_ssvd = "SSVD",
+                                           levels_age = c("0-4", "5-9"),
+                                           levels_sex = NULL,
+                                           joint = NULL,
+                                           agesex = "age",
+                                           get_matrix = TRUE,
+                                           n_comp = 3L)
+  ans_expected <- Matrix::Matrix(1, nr = 2, nc = 3, 
+                                 dimnames = list(c("0-4", "5-9"), NULL))
+  expect_equal(ans_obtained, ans_expected)
+})
+
 test_that("'get_matrix_or_offset_svd' works with age main effect, type is total, offset", {
     ssvd <- sim_ssvd()
     ans_obtained <- get_matrix_or_offset_svd(ssvd,
+                                             v = "v1",
+                                             nm_ssvd = "SSVD",
                                              levels_age = c("0 to 4", "5 to 9"),
                                              levels_sex = NULL,
                                              joint = NULL,
@@ -29,6 +70,8 @@ test_that("'get_matrix_or_offset_svd' works with age main effect, type is total,
 test_that("'get_matrix_or_offset_svd' works with sex-age interaction, type is joint, offset", {
     ssvd <- sim_ssvd()
     ans_obtained <- get_matrix_or_offset_svd(ssvd,
+                                             v = "v1",
+                                             nm_ssvd = "SSVD",
                                              levels_age = c("0-4", "5-9"),
                                              levels_sex = c("Male", "Female"),
                                              joint = TRUE,
@@ -42,6 +85,8 @@ test_that("'get_matrix_or_offset_svd' works with sex-age interaction, type is jo
 test_that("'get_matrix_or_offset_svd' works with age-sex interaction, type is indep, matrix", {
   ssvd <- sim_ssvd()
   ans_obtained <- get_matrix_or_offset_svd(ssvd,
+                                           v = "v1",
+                                           nm_ssvd = "SSVD",
                                            levels_age = c("0-4", "5-9"),
                                            levels_sexgender = c("Female", "Male"),
                                            joint = FALSE,
@@ -58,6 +103,8 @@ test_that("'get_matrix_or_offset_svd' works with age-sex interaction, type is in
 test_that("'get_matrix_or_offset_svd' works with age-sex interaction, type is joint, offset, non-standard labels", {
   ssvd <- sim_ssvd()
   ans_obtained <- get_matrix_or_offset_svd(ssvd,
+                                           v = "v1",
+                                           nm_ssvd = "SSVD",
                                            levels_age = c("0 to 4", "5--9"),
                                            levels_sexgender = c("M", "F"),
                                            joint = FALSE,
@@ -71,46 +118,86 @@ test_that("'get_matrix_or_offset_svd' works with age-sex interaction, type is jo
   expect_identical(ans_obtained, ans_expected)
 })
 
+test_that("'get_matrix_or_offset_svd' returns expected error when 'v' incorrect - one version present", {
+  ssvd <- sim_ssvd()
+  expect_error(get_matrix_or_offset_svd(ssvd,
+                                        v = "wrong",
+                                        nm_ssvd = "SSVD",
+                                        levels_age = c("0-4", "5-9", "0-4"),
+                                        levels_sexgender = c("F", "M"),
+                                        joint = FALSE,
+                                        agesex = "age:sex",
+                                        get_matrix = TRUE,
+                                        n_comp = 5),
+               "Invalid value for version parameter `v`.")
+})
+
+test_that("'get_matrix_or_offset_svd' returns expected error when 'v' incorrect - two versions present", {
+  ssvd <- sim_ssvd()
+  data1 <- ssvd$data
+  data2 <- ssvd$data
+  data2$version <- "v2"
+  ssvd$data <- rbind(data1, data2)
+  expect_error(get_matrix_or_offset_svd(ssvd,
+                                        v = "wrong",
+                                        nm_ssvd = "SSVD",
+                                        levels_age = c("0-4", "5-9", "0-4"),
+                                        levels_sexgender = c("F", "M"),
+                                        joint = FALSE,
+                                        agesex = "age:sex",
+                                        get_matrix = TRUE,
+                                        n_comp = 5),
+               "Invalid value for version parameter `v`.")
+})
+
 test_that("'get_matrix_or_offset_svd' returns expected error when 'levels_age' has duplicates", {
-    ssvd <- sim_ssvd()
-    expect_error(get_matrix_or_offset_svd(ssvd,
-                                          levels_age = c("0-4", "5-9", "0-4"),
-                                          levels_sexgender = c("F", "M"),
-                                          joint = FALSE,
-                                          agesex = "age:sex",
-                                          get_matrix = TRUE,
-                                          n_comp = 5),
-                 "Internal error: `levels_age` has duplicates.")
+  ssvd <- sim_ssvd()
+  expect_error(get_matrix_or_offset_svd(ssvd,
+                                        v = "v1",
+                                        nm_ssvd = "SSVD",
+                                        levels_age = c("0-4", "5-9", "0-4"),
+                                        levels_sexgender = c("F", "M"),
+                                        joint = FALSE,
+                                        agesex = "age:sex",
+                                        get_matrix = TRUE,
+                                        n_comp = 5),
+               "Internal error: `levels_age` has duplicates.")
 })
 
 test_that("'get_matrix_or_offset_svd' returns expected error when 'levels_sexgender' has duplicates", {
-    ssvd <- sim_ssvd()
-    expect_error(get_matrix_or_offset_svd(ssvd,
-                                          levels_age = c("0-4", "5-9"),
-                                          levels_sexgender = c("F", "M", "M"),
-                                          joint = FALSE,
-                                          agesex = "age:sex",
-                                          get_matrix = TRUE,
-                                          n_comp = 5),
-                 "Internal error: `levels_sexgender` has duplicates.")
+  ssvd <- sim_ssvd()
+  expect_error(get_matrix_or_offset_svd(ssvd,
+                                        v = "v1",
+                                        nm_ssvd = "SSVD",
+                                        levels_age = c("0-4", "5-9"),
+                                        levels_sexgender = c("F", "M", "M"),
+                                        joint = FALSE,
+                                        agesex = "age:sex",
+                                        get_matrix = TRUE,
+                                        n_comp = 5),
+               "Internal error: `levels_sexgender` has duplicates.")
 })
 
 
 test_that("'get_matrix_or_offset_svd' returns expected error with illegal value for agesex", {
-    ssvd <- sim_ssvd()
-    expect_error(get_matrix_or_offset_svd(ssvd,
-                                          levels_age = c("0-4", "5-9"),
-                                          levels_sexgender = c("F", "M"),
-                                          joint = FALSE,
-                                          agesex = "other",
-                                          get_matrix = TRUE,
-                                          n_comp = 5),
-                 "Internal error: unexpected value for `agesex`.")
+  ssvd <- sim_ssvd()
+  expect_error(get_matrix_or_offset_svd(ssvd,
+                                        v = "v1",
+                                        nm_ssvd = "SSVD",
+                                        levels_age = c("0-4", "5-9"),
+                                        levels_sexgender = c("F", "M"),
+                                        joint = FALSE,
+                                        agesex = "other",
+                                        get_matrix = TRUE,
+                                        n_comp = 5),
+               "Internal error: unexpected value for `agesex`.")
 })
 
 test_that("'get_matrix_or_offset_svd' returns expected error with illegal value for age label", {
     ssvd <- sim_ssvd()
     expect_error(get_matrix_or_offset_svd(ssvd,
+                                          v = "v1",
+                                          nm_ssvd = "SSVD",
                                           levels_age = c("0-4", "wrong"),
                                           levels_sexgender = c("F", "M"),
                                           joint = FALSE,
@@ -121,20 +208,24 @@ test_that("'get_matrix_or_offset_svd' returns expected error with illegal value
 })
 
 test_that("'get_matrix_or_offset_svd' returns expected error with illegal value for age label", {
-    ssvd <- sim_ssvd()
-    expect_error(get_matrix_or_offset_svd(ssvd,
-                                          levels_age = c("0-4", "5-9"),
-                                          levels_sexgender = c("F", "wrong"),
-                                          joint = FALSE,
-                                          agesex = "sex:age",
-                                          get_matrix = TRUE,
-                                          n_comp = 5),
-                 "Unable to parse sex/gender labels when processing SVD prior.")
+  ssvd <- sim_ssvd()
+  expect_error(get_matrix_or_offset_svd(ssvd,
+                                        v = "v1",
+                                        nm_ssvd = "SSVD",
+                                        levels_age = c("0-4", "5-9"),
+                                        levels_sexgender = c("F", "wrong"),
+                                        joint = FALSE,
+                                        agesex = "sex:age",
+                                        get_matrix = TRUE,
+                                        n_comp = 5),
+               "Unable to parse sex/gender labels when processing SVD prior.")
 })
 
 test_that("'get_matrix_or_offset_svd' returns expected error when can't align age labels", {
   ssvd <- sim_ssvd()
   expect_error(get_matrix_or_offset_svd(ssvd,
+                                        v = "v1",
+                                        nm_ssvd = "SSVD",
                                         levels_age = c("0---4", "5+"),
                                         levels_sexgender = c("F", "M"),
                                         joint = FALSE,
@@ -147,6 +238,8 @@ test_that("'get_matrix_or_offset_svd' returns expected error when can't align ag
 test_that("'get_matrix_or_offset_svd' returns expected error when can't parse sex/gender labels", {
   ssvd <- sim_ssvd()
   expect_error(get_matrix_or_offset_svd(ssvd,
+                                        v = "v1",
+                                        nm_ssvd = "SSVD",
                                         levels_age = c("0-4", "5-9"),
                                         levels_sexgender = c("M", "FFF"),
                                         joint = FALSE,
@@ -159,6 +252,8 @@ test_that("'get_matrix_or_offset_svd' returns expected error when can't parse se
 test_that("'get_matrix_or_offset_svd' returns expected error when can't align sex/gender labels", {
   ssvd <- sim_ssvd()
   expect_error(get_matrix_or_offset_svd(ssvd,
+                                        v = "v1",
+                                        nm_ssvd = "SSVD",
                                         levels_age = c("0-4", "5-9"),
                                         levels_sexgender = "M",
                                         joint = FALSE,
@@ -171,13 +266,28 @@ test_that("'get_matrix_or_offset_svd' returns expected error when can't align se
 
 ## 'get_n_comp' -------------------------------------------------------------------
 
-test_that("'get_n_comp' works", {
+test_that("'get_n_comp' works - total is present", {
   ssvd <- sim_ssvd()
   ans_obtained <- get_n_comp(ssvd)
   ans_expected <- 10L
   expect_identical(ans_obtained, ans_expected)
 })
 
+test_that("'get_n_comp' works - total not present but joint present", {
+  ssvd <- sim_ssvd()
+  ssvd$data$type <- "joint"
+  ans_obtained <- get_n_comp(ssvd)
+  ans_expected <- 10L
+  expect_identical(ans_obtained, ans_expected)
+})
+
+test_that("'get_n_comp' throws error - total and joint not present", {
+  ssvd <- sim_ssvd()
+  ssvd$data$type <- "indep"
+  expect_error(get_n_comp(ssvd),
+               "Internal error: Object does not have 'total' or 'joint'.")
+})
+
 
 ## 'has_sexgender' ------------------------------------------------------------
 
